Developer's Guide
=================

This section contains information for Developers who wish to work on
Zuul itself.  This information is not necessary for the operation of
Zuul, though advanced users may find it interesting.

.. autoclass:: zuul.scheduler.Scheduler

.. toctree::
   :maxdepth: 1

   datamodel
   drivers
   triggers
   testing
   metrics
   docs
   ansible
   javascript
   specs/index
   zookeeper
   model-changelog
   releasenotes
